# `auxi` Release Notes
This file reports the details of each `auxi` release from newest to oldest.


## 0.3.0
In this release a significant number of additions were made. These included:
* added a material physical property package under tools;
* added a transport phenomena package under tools (#57);
* added a front page to the GitHub repository (#69);
* cleaned up the root directory of the repository (#70);
* added system documentation to make contributions easy (#33);

### Release Details
Date:       <<add release date here>>
Maintainer: <<add name of maintainer that created the release>>

### Issues Addressed
<<list the issues addressed in this release here>>


## <<add version number here>>
<<add a description of the highlights of this release here>>

### Release Details
Date:       <<add release date here>>
Maintainer: <<add name of maintainer that created the release>>

### Issues Addressed
<<list the issues addressed in this release here>>
